@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Bencher::Scenario;
 
-our $DATE = '2016-05-23'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2016-07-13'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,6 +11,8 @@ use Moose;
 use namespace::autoclean;
 
 use Bencher::Backend;
+use Dist::Zilla::File::InMemory;
+use File::Slurper qw(read_binary);
 use File::Spec::Functions qw(catfile);
 use Module::Load;
 
@@ -24,6 +26,7 @@ with (
     'Dist::Zilla::Role::FileFinderUser' => {
         default_finders => [':InstallModules'],
     },
+    'Dist::Zilla::Role::PrereqSource',
 );
 
 # either provide filename or filename+filecontent
@@ -186,6 +189,26 @@ sub munge_files {
     return;
 }
 
+# we abuse this PrereqSource phase (comes after FileMunger phase, which is after
+# Pod::Weaver::Plugin::Bencher::Scenario) to add files generated by it
+
+sub register_prereqs {
+    my $self = shift;
+    my $tempdir = $self->zilla->{_pwp_bs_tempdir};
+    return unless $tempdir;
+
+    opendir my($dh), $tempdir or die;
+    for my $fname (readdir $dh) {
+        next unless $fname =~ /\.png\z/;
+        my $file = Dist::Zilla::File::InMemory->new(
+            name => "share/images/$fname",
+            encoded_content => read_binary("$tempdir/$fname"),
+        );
+        $self->log(["Adding chart image file %s into share/images/", $fname]);
+        $self->add_file($file);
+    }
+}
+
 __PACKAGE__->meta->make_immutable;
 1;
 # ABSTRACT: Plugin to use when building Bencher::Scenario::* distribution
@@ -202,7 +225,7 @@ Dist::Zilla::Plugin::Bencher::Scenario - Plugin to use when building Bencher::Sc
 
 =head1 VERSION
 
-This document describes version 0.12 of Dist::Zilla::Plugin::Bencher::Scenario (from Perl distribution Dist-Zilla-Plugin-Bencher-Scenario), released on 2016-05-23.
+This document describes version 0.13 of Dist::Zilla::Plugin::Bencher::Scenario (from Perl distribution Dist-Zilla-Plugin-Bencher-Scenario), released on 2016-07-13.
 
 =head1 SYNOPSIS
 
@@ -223,6 +246,8 @@ It currently dos the following:
 
 =item * Fill-in ABSTRACT from scenario's summary
 
+=item * Add chart images generated by L<Pod::Weaver::Plugin::Bencher::Scenario> into the build
+
 =back
 
 =for Pod::Coverage .+
